@@ -72,9 +72,10 @@ void KAboutPluginDialogPrivate::init(KAboutPluginDialog::Options opt)
     QTabWidget *tabWidget = new QTabWidget;
     tabWidget->setUsesScrollButtons(false);
 
+    QString extraInformation;
     // Set up the first page...
-    QWidget *aboutWidget = createAboutWidget(pluginMetaData.description(),
-                                             pluginMetaData.extraInformation(),
+    QWidget *aboutWidget = createAboutWidget(pluginMetaData.description(), //
+                                             extraInformation,
                                              pluginMetaData.copyrightText(),
                                              pluginMetaData.website(),
                                              {pluginLicense},
@@ -106,3 +107,5 @@ void KAboutPluginDialogPrivate::init(KAboutPluginDialog::Options opt)
 
     createForm(titleWidget, tabWidget, q);
 }
+
+#include "moc_kaboutplugindialog.cpp"
